@@ -486,7 +486,7 @@ static char * process_query(konf_buf_t *tbuf, konf_tree_t * conf, char *str)
 
 #ifdef DEBUG
 	/* Print whole tree */
-	konf_tree_fprintf(conf, stderr, NULL, -1, -1, BOOL_TRUE, 0);
+	konf_tree_fprintf(conf, stderr, NULL, -1, -1, BOOL_TRUE, BOOL_TRUE, 0);
 #endif
 
 	/* Free resources */
@@ -559,6 +559,7 @@ static int dump_running_config(int sock, konf_tree_t *conf, konf_query_t *query)
 		konf_query__get_pwdc(query) - 1,
 		konf_query__get_depth(query),
 		konf_query__get_seq(query),
+		konf_query__get_splitter(query),
 		0);
 	if (!filename) {
 		fprintf(fd, "\n");
